@@ -1,8 +1,8 @@
 from .logger import Logger
 from .ost import OST
 from .sign import Sign, CRCCCITT, CRCXMODEM
-from .string import String
+from .string import randomstr
 from .digits import Digits
-from .date import DateTool
+from .date import dateutil
 
-__version__ = "0.3.11"
+__version__ = "0.4.0"
