@@ -6,7 +6,7 @@ import datetime
 import calendar
 
 
-class DateTool(object):
+class dateutil(object):
 
     @classmethod
     def get_current_month_range(self):
