@@ -6,7 +6,7 @@ from datetime import datetime, date
 import pytz
 
 
-class DateTime(object):
+class timeutil(object):
 
     def __init__(self, date, format="%Y-%m-%d %H:%M:%S", tz="UTC"):
         if type(date) is datetime:
