@@ -6,7 +6,7 @@ from string import ascii_letters, digits
 from random import choice
 
 
-class String(object):
+class randomstr(object):
 
     @classmethod
     def generate(cls, length=8):
