@@ -3,7 +3,7 @@
 # @Author  : Kevin Kong (kfx2007@163.com)
 
 import unittest
-from autils.date import DateTool
+from autils.date import dateutil
 
 class TestDateTool(unittest.TestCase):
 
@@ -13,7 +13,7 @@ class TestDateTool(unittest.TestCase):
         cls.month = 2
 
     def test_get_month_range(self):
-        first_day, last_day = DateTool.get_first_and_last_day(self.year,self.month)
+        first_day, last_day = dateutil.get_first_and_last_day(self.year,self.month)
         print(first_day,last_day)
     
 
