@@ -1,5 +1,5 @@
 import unittest
-from autils.datetime import DateTime
+from autils.datetime import timeutil
 from datetime import datetime, date
 
 
@@ -7,7 +7,7 @@ class TestDateTime(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        cls.date = DateTime("2019-12-31 00:00:00")
+        cls.date = timeutil("2019-12-31 00:00:00")
 
     def test_convert_utc(self):
         """测试转换UTC"""
